@@ -1,2 +1,2 @@
 from . import csvload
-import pandas
\ No newline at end of file
+import csv
\ No newline at end of file
